@@ -20,7 +20,7 @@
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
  * @copyright  2003-2008 PgPool Global Development Group
- * @version    SVN: $Id: status.php,v 1.9 2008/02/06 08:41:32 yamaguti Exp $
+ * @version    SVN: $Id: status.php,v 1.10 2010/07/22 05:17:47 anzai Exp $
  */
 
 require_once('common.php');
@@ -52,6 +52,7 @@ if(isset($_POST['action'])) {
  */
 
 $tpl->assign('c', _PGPOOL2_CMD_OPTION_C);
+$tpl->assign('D', _PGPOOL2_CMD_OPTION_LARGE_D);
 $tpl->assign('d', _PGPOOL2_CMD_OPTION_D);
 $tpl->assign('m', _PGPOOL2_CMD_OPTION_M);
 $tpl->assign('n', _PGPOOL2_CMD_OPTION_N);
@@ -67,6 +68,9 @@ switch ($action) {
         if(isset($_POST['c'])) {
             $args = $args . "-c ";
         }
+        if(isset($_POST['D'])) {
+            $args = $args . "-D ";
+        }
         if(isset($_POST['d'])) {
             $args = $args . "-d ";
         }
@@ -164,6 +168,9 @@ switch ($action) {
         if(isset($_POST['c'])) {
             $args = $args . "-c ";
         }
+        if(isset($_POST['D'])) {
+            $args = $args . "-D ";
+        }
         if(isset($_POST['d'])) {
             $args = $args . "-d ";
         }
